<?php
/**
 * RCP Signup
 *
 * Registers customers in Help Scout when they register through RCP
 *
 * @package   rcp-help-scout
 * @copyright Copyright (c) 2019, Restrict Content Pro team
 * @license   GPL2+
 * @since     1.0
 */

if( ! class_exists( 'Curl' ) ) {

	include_once RCP_HELPSCOUT_PLUGIN_DIR . 'includes/src/curl.php';

}

if( ! class_exists( 'CurlResponse' ) ) {

	include_once RCP_HELPSCOUT_PLUGIN_DIR . 'includes/src/curlResponse.php';

}

if( ! class_exists( 'ApiClient' ) ) {

	include_once RCP_HELPSCOUT_PLUGIN_DIR . 'includes/src/HelpScout/ApiClient.php';

}

use HelpScout\ApiClient;

/**
 * Class PW_RCP_Help_Scout_Signup
 *
 * @since 1.0
 */
class PW_RCP_Help_Scout_Signup {

	private $api_key = '';
	private $secret  = '';
	private $email   = '';

	/**
	 * PW_RCP_Help_Scout_Signup constructor.
	 *
	 * @since 1.0
	 */
	public function __construct() {

		global $rcp_options;

		if( ! empty( $rcp_options['hs_api_key'] ) ) {
			$this->api_key = trim( $rcp_options[ 'hs_api_key' ] );
		}

		if( ! empty( $rcp_options['hs_secret_key'] ) ) {
			$this->secret = trim( $rcp_options[ 'hs_secret_key' ] );
		}

		if( ! empty( $rcp_options['hs_email'] ) ) {
			$this->email = trim( $rcp_options[ 'hs_email' ] );
		}

		add_action( 'rcp_form_processing', array( $this, 'rcp_form_processing' ), 10, 3 );
	}

	/**
	 * Create customer during registration process.
	 *
	 * @param array $postdata Posted data.
	 * @param int   $user_id  ID of the user.
	 * @param float $price    Price of the membership.
	 *
	 * @since 1.0
	 */
	public function rcp_form_processing( $postdata, $user_id, $price ) {
		$this->create_customer( $user_id );
	}

	/**
	 * Create customer in Help Scout
	 *
	 * @param int $user_id
	 *
	 * @since 1.0
	 * @return void
	 */
	public function create_customer( $user_id ) {

		$user = new WP_User( $user_id );

		try {

			$client = ApiClient::getInstance();
			$client->setKey( $this->api_key );

			$customer = new \HelpScout\model\Customer();
			$customer->setFirstName( $user->user_firstname );
			$customer->setLastName( $user->user_lastname );

			// Emails: at least one email is required
			$emailWork = new \HelpScout\model\customer\EmailEntry();
			$emailWork->setValue( $user->user_email );
			$emailWork->setLocation( "work" );

			$customer->setEmails( array( $emailWork ) );

			$client->createCustomer( $customer );

		} catch( Exception $e ) {

		}
	}

}
new PW_RCP_Help_Scout_Signup;